@@ -17,10 +17,10 @@
 # specific language governing permissions and limitations
 # under the License.
 
+import json
 
 from gstack import app
-from gstack.controllers import helper
-import json
+from gstack import helpers
 
 
 @app.route('/discovery/v1/apis/compute/v1/rest', methods=['GET'])
@@ -28,10 +28,9 @@ def discovery():
     with open(app.config['DATA'] + '/v1.json') as template:
         discovery_template = json.loads(template.read())
 
-    discovery_template[
-        'baseUrl'] = helper.get_root_url() + '/' + app.config['PATH']
+    discovery_template['baseUrl'] = helpers.get_root_url() + '/' + app.config['PATH']
     discovery_template['basePath'] = '/' + app.config['PATH']
-    discovery_template['rootUrl'] = helper.get_root_url() + '/'
+    discovery_template['rootUrl'] = helpers.get_root_url() + '/'
     discovery_template['servicePath'] = app.config['PATH']
 
-    return helper.create_response(data=discovery_template)
+    return helpers.create_response(data=discovery_template)
